<?php
/* Set content width
----------------------------------------------------------------------------- */
if ( ! isset( $content_width ) ) $content_width = 1140;

/* Load framework
----------------------------------------------------------------------------- */

if ( file_exists( get_template_directory(). '/inc/themeora-framework-init.php') ) {
    include_once ( get_template_directory(). '/inc/themeora-framework-init.php' );
}


/* General theme setup options
----------------------------------------------------------------------------- */

if ( ! function_exists( 'themeora_theme_setup' ) ) :

    function themeora_theme_setup() {
        
        /* Register Navigation 
        ------------------------------------------------------------------------------*/
        register_nav_menus( array(
            'primary_menu' => __( 'Primary Menu', 'ascent-free' ),
            'social_menu' => __( 'Social Menu', 'ascent-free' )
        ));
        
        /* Load editor style
        ------------------------------------------------------------------------------*/
        add_editor_style( 'custom-editor-style.css' );

        /* Load text domain
        ------------------------------------------------------------------------------*/
        load_theme_textdomain('ascent-free', get_template_directory_uri() . "/languages/");

        /* Add various theme support options
        ----------------------------------------------------------------------------- */

        add_theme_support( 'automatic-feed-links' );
        add_theme_support( 'post-thumbnails' );
        add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
        //remove_theme_support( 'custom-background' );
        //add_theme_support( 'post-formats', array( 'audio', 'gallery', 'image', 'quote', 'video', 'link' ) );
        add_post_type_support( 'page', 'excerpt' );
        add_theme_support( "title-tag" );
        // Add backwards compatibility for title-tag
        if ( ! function_exists( '_wp_render_title_tag' ) ) {
            function theme_slug_render_title() {
            ?>
                <title><?php wp_title( '|', true, 'right' ); ?></title>
                <?php
            }
            add_action( 'wp_head', 'theme_slug_render_title' );
        }
        /* Setup the post thumbnail size for the theme.
        ------------------------------------------------------------------------------ */

        set_post_thumbnail_size( 1140, 700, true ); //this is wide enough for 12 cols of the bootstrap grid system
        /* add custom image sizes */
        add_image_size( 'themeora-thumbnail-span-3', 260, 210, true ); //spans 3 cols of the bootstrap grid
        add_image_size( 'themeora-thumbnail-span-4', 360, 290, true ); //spans 4 cols of the bootstrap grid
        add_image_size( 'themeora-thumbnail-span-5', 455, 366, true ); //spans 5 cols of the bootstrap grid
        add_image_size( 'themeora-thumbnail-span-6', 550, 442, true ); //spans 6 cols of the bootstrap grid
        add_image_size( 'themeora-thumbnail-span-7', 650, 523, true ); //spans 7 cols of the bootstrap grid
        add_image_size( 'themeora-thumbnail-span-8', 750, 603, true ); //spans 8 cols of the bootstrap grid
        add_image_size( 'themeora-thumbnail-span-9', 850, 683, true ); //spans 9 cols of the bootstrap grid
        
        /* portfolio sizes */
        add_image_size( 'portfolio-1140x1350',1140, 1350, true ); //portfolio 1140 x 1350
        add_image_size( 'portfolio-555x750',555, 750, true ); //portfolio 555 x 750
        add_image_size( 'portfolio-360x485', 360, 485, true ); //portfolio 360x485px
        add_image_size( 'portfolio-263x355',263, 355, true ); //portfolio 263x355
        add_image_size( 'portfolio-165x223',165, 223, true ); //portfolio 165x223
        
    }

endif; //themeora_theme_setup

add_action('after_setup_theme', 'themeora_theme_setup');


/* The function to register / enqueue theme scripts
------------------------------------------------------------------------------- */

if ( ! function_exists( 'themeora_enqueue_scripts' ) ) :

    function themeora_enqueue_scripts() {
        /* Load Default Google fonts */
        wp_enqueue_style( 'google-fonts', '//fonts.googleapis.com/css?family=Montserrat:400,300,500,700|Open+Sans:400,700' );
        
        /* load styles */
        wp_enqueue_style( 'themeora-bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
        wp_enqueue_style( 'themeora-fontAwesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
        wp_enqueue_style( 'themeora-edd', get_template_directory_uri() . '/inc/edd/edd.css' );
        wp_enqueue_style( 'slidebars', get_template_directory_uri() . '/css/slidebars.css' );
        wp_enqueue_style( 'themeora-base-style', get_stylesheet_uri() );
        
        // Add styling options from customizer
        $themeora_user_css = themeora_customizer_css();        
        wp_add_inline_style( 'themeora-base-style', $themeora_user_css );
        
        /* Scripts */
        if ( !is_admin() ){ //add support for threaded comments
            if ( is_singular() AND comments_open() AND ( 1 == get_option('thread_comments') ))
            wp_enqueue_script( 'comment-reply' );
        }
        
        //load modernizer
        wp_enqueue_script( 'modernizer', get_template_directory_uri() . '/js/modernizr.custom.js', null, null, true );
        
        //load imagesloaded.js
        wp_enqueue_script( 'imagesloaded', get_template_directory_uri() . '/js/imagesloaded.pkgd.min.js', 'jquery', null, true );
        
        //load retina.js
        wp_enqueue_script( 'retina', get_template_directory_uri() . '/js/retina.js', null, null, true );
        
        //slidebars menu
        wp_enqueue_script( 'slidebars', get_template_directory_uri() . '/js/slidebars.js', null, null, true );
        
        //register the main js file
        wp_enqueue_script( 'themeora-custom', get_template_directory_uri() . '/js/custom.js', 'jquery', null, true );
    }
endif; //themeora_enqueue_scripts

add_action( 'wp_enqueue_scripts', 'themeora_enqueue_scripts' );


/* Load Default Google fonts for admin
 ------------------------------------------------------------------------------- */
function themeora_admin_fonts( $hook_suffix ) {
    wp_enqueue_style( 'themeora-google-fonts', '//fonts.googleapis.com/css?family=Montserrat:400,300,500,700|Open+Sans:400,700' );
    wp_enqueue_style( 'themeora-fontAwesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
}
add_action( 'admin_enqueue_scripts', 'themeora_admin_fonts' );


/* Load respond.js and html5shiv
------------------------------------------------------------------------------- */
function themeora_head_js() {
    echo '<!--[if lt IE 9]>' . "\n";
    echo '<script src="' . esc_url( get_template_directory_uri() . '/js/html5shiv.js' ) . '"></script>' . "\n";
    echo '<script src="' . esc_url( get_template_directory_uri() . '/js/respond.js' ) . '"></script>' . "\n";
    echo '<![endif]-->' . "\n";
}
add_action( 'wp_head', 'themeora_head_js' );

/* The function to register sidebars & widgets
    ------------------------------------------------------------------------------- */

if ( ! function_exists( 'themeora_widgets_init' ) ) :

    function themeora_widgets_init() {
        
        /* Register widget areas
        --------------------------------------------------------------------------*/

        register_sidebar( array(
            'name' => __( 'Blog Sidebar', 'ascent-free' ),
            'id' => 'blog-sidebar',
            'description' => __( 'Default blog sidebar stuff', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="styled-box widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));

        register_sidebar( array(
            'name' => __( 'Page Sidebar', 'ascent-free' ),
            'id' => 'page-sidebar',
            'description' => __( 'Default page sidebar stuff', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="styled-box widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));
        
        register_sidebar( array(
            'name' => __( 'Shop Sidebar', 'ascent-free' ),
            'id' => 'shop-sidebar',
            'description' => __( 'Sidebar for the single EDD shop', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="styled-box widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));
        
        register_sidebar( array(
            'name' => __( 'Checkout Sidebar', 'ascent-free' ),
            'id' => 'checkout-sidebar',
            'description' => __( 'Sidebar for the EDD checkout', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="styled-box widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));
        
        register_sidebar( array(
            'name' => __( 'Footer Top Widget', 'ascent-free' ),
            'id' => 'footer-widget-top',
            'description' => __( 'Footer Top Widget', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));
        
        register_sidebar( array(
            'name' => __( 'Footer Middle Widget', 'ascent-free' ),
            'id' => 'footer-widget-middle',
            'description' => __( 'Footer Middle Widget', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));
        
        register_sidebar( array(
            'name' => __( 'Footer bottom Widget', 'ascent-free' ),
            'id' => 'footer-widget-bottom',
            'description' => __( 'Footer Bottom Widget', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));
        
        register_sidebar( array(
            'name' => __( 'Footer Terms Widget', 'ascent-free' ),
            'id' => 'footer-widget-terms',
            'description' => __( 'Footer Terms Widget', 'ascent-free' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="">',
            'after_title' => '</h3>',
        ));

    }

endif; //themeora_widgets_init

add_action( 'widgets_init', 'themeora_widgets_init' );


/* Load theme functions
------------------------------------------------------------------------------ */

require 'inc/functions-utility.php'; // Helper functions
require 'inc/functions-templates.php'; // Template functions
require 'inc/edd/functions.php'; // Custom functions for EDD